# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('offer', '0003_auto_20161120_1707'),
        ('cms', '0016_auto_20160608_1535'),
        ('cms_oscar', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='OscarOffer',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='cms_oscar_oscaroffer', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('limit', models.PositiveIntegerField(default=6)),
                ('renderTemplate', models.CharField(default=b'cms_oscar/Latest.html', max_length=150, verbose_name=b'Latest Template', blank=True, choices=[(b'cms_oscar/Latest.html', 'Default'), (b'cms_oscar/Products.html', 'Products')])),
                ('offer', models.ForeignKey(related_name='+', default=None, blank=True, to='offer.ConditionalOffer', null=True, on_delete=models.CASCADE)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.AlterField(
            model_name='oscarfeatured',
            name='renderTemplate',
            field=models.CharField(default=b'cms_oscar/Featured.html', max_length=150, verbose_name=b'Featured Template', blank=True, choices=[(b'cms_oscar/Featured.html', 'Default'), (b'cms_oscar/Products.html', 'Products')]),
        ),
        migrations.AlterField(
            model_name='oscarlatest',
            name='renderTemplate',
            field=models.CharField(default=b'cms_oscar/Latest.html', max_length=150, verbose_name=b'Latest Template', blank=True, choices=[(b'cms_oscar/Latest.html', 'Default'), (b'cms_oscar/Products.html', 'Products')]),
        ),
    ]
